==> 2.4.zip: piwigo/language/el_GR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = 'Όλα τα υπο-άλμπουμ των ιδιωτικών άλμπουμ γίνονται ιδιωτικά';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Ως προληπτικό μέτρο, οι παρακάτω επεκτάσεις έχουν απενεργοποιηθεί. Θα πρέπει να ελέγξετε για αναβαθμίσεις επεκτάσεων πριν από την επανενεργοποίηση τους:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Ως προληπτικό μέτρο, τα ακόλουθα Θέματα έχουν απενεργοποιηθεί. Θα πρέπει να ελέγξετε για  αναβάθμιση Θεμάτων πριν από την επανενεργοποίηση τους:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'Σε <i>%s</ i>, πριν <b>?></b>, εισάγετε:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Μόνο ένας διαχειριστής μπορεί να τρέξει αναβάθμιση: Παρακαλώ συνδεθείτε παρακάτω. ';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Μόνο τα προθέματα μικρογραφιών και η διεύθυνση ηλεκτρονικού ταχυδρομείου του webmaster έχουν σωθεί από προηγούμενες διαμορφώσεις';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Εκτελέστε έναν έλεγχο συντήρησης [Διαχείριση>Εργαλεία>Συντήρηση] Αν αντιμετωπίζετε κάποιο πρόβλημα.';
$lang['SQL queries'] = 'ερωτήματα SQL';
$lang['Statistics'] = 'Στατιστικά';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Η σελίδα αυτή προτείνει την αναβάθμιση της βάσης δεδομένων από την παλιά έκδοση Piwigo σας στη νέα έκδοση. Ο βοηθός αναβάθμισης νομίζει ότι τρέχετε την <strong>έκδοση %s</strong> (ή κάτι τέτοιο).';
$lang['Upgrade from version %s to %s'] = 'Αναβάμηση απο έκδοση %s σε %s';
$lang['Upgrade informations'] = 'Πληροφορίες Αναβάθμησης';
$lang['Upgrade'] = 'Αναβάθμηση';
$lang['User permissions and group permissions have been erased'] = 'Τα δικαιώματα χρηστών και ομάδων έχουν διαγραφτεί';
$lang['You do not have access rights to run upgrade'] = 'Δεν έχετε δικαιώματα πρόσβασης για την εκτέλεση αναβάθμισης';
$lang['total SQL time'] = 'Συνολικός χρόνος SQL';
$lang['total upgrade time'] = 'Συνολικός χρόνος αναβάθμησης';
?>

==> 14.5.0.zip: piwigo/language/el_GR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = 'Όλα τα υπο-άλμπουμ των ιδιωτικών άλμπουμ γίνονται ιδιωτικά';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Ως προληπτικό μέτρο, οι παρακάτω επεκτάσεις έχουν απενεργοποιηθεί. Θα πρέπει να ελέγξετε για αναβαθμίσεις επεκτάσεων πριν από την επανενεργοποίηση τους:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Ως προληπτικό μέτρο, τα ακόλουθα Θέματα έχουν απενεργοποιηθεί. Θα πρέπει να ελέγξετε για  αναβάθμιση Θεμάτων πριν από την επανενεργοποίηση τους:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'Σε <i>%s</ i>, πριν <b>?></b>, εισάγετε:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Μόνο ένας διαχειριστής μπορεί να τρέξει αναβάθμιση: Παρακαλώ συνδεθείτε παρακάτω. ';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Μόνο τα προθέματα μικρογραφιών και η διεύθυνση ηλεκτρονικού ταχυδρομείου του webmaster έχουν σωθεί από προηγούμενες διαμορφώσεις';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Εκτελέστε έναν έλεγχο συντήρησης [Διαχείριση>Εργαλεία>Συντήρηση] Αν αντιμετωπίζετε κάποιο πρόβλημα.';
$lang['SQL queries'] = 'ερωτήματα SQL';
$lang['Statistics'] = 'Στατιστικά';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Η σελίδα αυτή προτείνει την αναβάθμιση της βάσης δεδομένων από την παλιά έκδοση Piwigo σας στη νέα έκδοση. Ο βοηθός αναβάθμισης νομίζει ότι τρέχετε την <strong>έκδοση %s</strong> (ή κάτι τέτοιο).';
$lang['Upgrade from version %s to %s'] = 'Αναβάμηση απο έκδοση %s σε %s';
$lang['Upgrade informations'] = 'Πληροφορίες Αναβάθμησης';
$lang['Upgrade'] = 'Αναβάθμηση';
$lang['User permissions and group permissions have been erased'] = 'Τα δικαιώματα χρηστών και ομάδων έχουν διαγραφτεί';
$lang['You do not have access rights to run upgrade'] = 'Δεν έχετε δικαιώματα πρόσβασης για την εκτέλεση αναβάθμισης';
$lang['total SQL time'] = 'Συνολικός χρόνος SQL';
$lang['total upgrade time'] = 'Συνολικός χρόνος αναβάθμησης';
$lang['Discover what\'s new in Piwigo %s'] = 'Ανακαλύψτε τι νέο υπάρχει στο Piwigo %s';
